summaryrefslogtreecommitdiffstats
path: root/core/java
diff options
context:
space:
mode:
authorWu-cheng Li <wuchengli@google.com>2010-03-29 17:21:28 +0800
committerWu-cheng Li <wuchengli@google.com>2010-04-10 09:33:15 +0800
commitc58b42327df5fbc826e2fcc2674ab6db0edfcd92 (patch)
tree531babba66efab35a2a78be5b0fc5116d0dc3945 /core/java
parent2a547829fe162c52ea1b1168f47d25fb1b40497d (diff)
downloadframeworks_base-c58b42327df5fbc826e2fcc2674ab6db0edfcd92.zip
frameworks_base-c58b42327df5fbc826e2fcc2674ab6db0edfcd92.tar.gz
frameworks_base-c58b42327df5fbc826e2fcc2674ab6db0edfcd92.tar.bz2
Add SCENE_MODE_BARCODE and FOCUS_MODE_EDOF.
bug:2544367 Change-Id: If122a7745e080f9e4bffb15dc4930d71f0421867
Diffstat (limited to 'core/java')
-rw-r--r--core/java/android/hardware/Camera.java21
1 files changed, 18 insertions, 3 deletions
diff --git a/core/java/android/hardware/Camera.java b/core/java/android/hardware/Camera.java
index 2495619..8687a89 100644
--- a/core/java/android/hardware/Camera.java
+++ b/core/java/android/hardware/Camera.java
@@ -824,6 +824,12 @@ public class Camera {
public static final String SCENE_MODE_PARTY = "party";
public static final String SCENE_MODE_CANDLELIGHT = "candlelight";
+ /**
+ * Applications are looking for a barcode. Camera driver will be
+ * optimized for barcode reading.
+ */
+ public static final String SCENE_MODE_BARCODE = "barcode";
+
// Values for focus mode settings.
/**
* Auto-focus mode.
@@ -845,6 +851,13 @@ public class Camera {
*/
public static final String FOCUS_MODE_FIXED = "fixed";
+ /**
+ * Extended depth of field (EDOF). Focusing is done digitally and
+ * continuously. Applications should not call {@link
+ * #autoFocus(AutoFocusCallback)} in this mode.
+ */
+ public static final String FOCUS_MODE_EDOF = "edof";
+
// Formats for setPreviewFormat and setPictureFormat.
private static final String PIXEL_FORMAT_YUV422SP = "yuv422sp";
private static final String PIXEL_FORMAT_YUV420SP = "yuv420sp";
@@ -1507,9 +1520,11 @@ public class Camera {
}
/**
* Sets the scene mode. Other parameters may be changed after changing
* scene mode. For example, flash and supported flash mode may be
* changed to "off" in night scene mode. After setting scene mode,
* applications should call getParameters to know if some parameters are
* changed.
*
@@ -1507,9 +1520,11 @@ public class Camera {
}
/**
- * Sets the scene mode. Other parameters may be changed after changing
- * scene mode. For example, flash and supported flash mode may be
- * changed to "off" in night scene mode. After setting scene mode,
+ * Sets the scene mode. Changing scene mode may override other
+ * parameters (such as flash mode, focus mode, white balance). For
+ * example, suppose originally flash mode is on and supported flash
+ * modes are on/off. In night scene mode, both flash mode and supported
+ * flash mode may be changed to off. After setting scene mode,
* applications should call getParameters to know if some parameters are
* changed.